@@ -5,13 +5,11 @@ name <- 'data'
 
 fail_individuals <-
     perIndividualQC(qcdir=qcdir, indir=indir, name=name,
-                    refSamplesFile=paste(qcdir, "/HapMap_ID2Pop.txt", sep=""),
-                    refColorsFile=paste(qcdir, "/HapMap_PopColors.txt", sep=""),
-                    do.run_check_sex=FALSE, do.run_check_ancestry=FALSE,
+                    do.run_check_sex=FALSE,
                     do.run_check_het_and_miss=FALSE,
                     do.run_check_relatedness=FALSE,
-                    prefixMergedDataset="data.HapMapIII",
-                    interactive=FALSE, verbose=FALSE)
+                    interactive=FALSE, verbose=FALSE,
+                    dont.ancestry_prediction = TRUE)
 
 context('Test cleanData')
 test_that('cleanData throws file error',{
@@ -21,9 +19,9 @@ test_that('cleanData throws file error',{
 })
 test_that('cleanData fails with missing check error', {
     expect_error(cleanData(qcdir=qcdir, indir=indir, name=name,
-                           filterAncestry=FALSE,
                            filterRelated=FALSE,
                            filterSex=FALSE, filterHeterozygosity=FALSE,
+                           filterAncestry=FALSE,
                            filterSampleMissingness=FALSE,
                            filterSNPMissingness=FALSE, filterHWE=FALSE,
                            filterMAF=FALSE),
@@ -33,8 +31,8 @@ test_that('cleanData fails with missing check error', {
 
 test_that('cleanData returns message with missing sample check', {
     expect_error(cleanData(qcdir=qcdir, indir=indir, name=name,
-                           filterAncestry=FALSE,
-                           filterRelated=FALSE, filterSampleMissingness=FALSE,
+                           filterRelated=FALSE, filterAncestry=FALSE,
+                           filterSampleMissingness=FALSE,
                            filterSex=FALSE, filterHeterozygosity=FALSE,
                            filterMAF=FALSE, filterSNPMissingness=FALSE,
                            filterHWE=FALSE),
